@@ -13,7 +13,7 @@ no warnings 'uninitialized';
 use vars qw($VERSION @EXPORT_FNC @EXPORT_CONST $MODPERL $SessionCleanup);
 
 BEGIN {
-	$VERSION = '1.0.0';
+	$VERSION = '1.0.1';
 	
 	require XSLoader;
 	XSLoader::load( __PACKAGE__, $VERSION );
@@ -117,11 +117,14 @@ __END__
 
 =head1 NAME
 
-PAB::DB::Driver::Sqlite3 - Perl wrapper to libsqlite3 and driver for PAB::DB class
+PAB3::DB::Driver::Sqlite3 - Perl wrapper to libsqlite3 and driver for the
+PAB3::DB class
+
+See more at L<the PAB3::DB manpage|PAB3::DB>
 
 =head1 SYNOPSIS
 
-  use PAB::DB::Driver::Sqlite3;
+  use PAB3::DB::Driver::Sqlite3;
   # functions and constants are exported by default
   
   $linkid = sqlite3_open( $db );
@@ -216,7 +219,7 @@ PAB::DB::Driver::Sqlite3 - Perl wrapper to libsqlite3 and driver for PAB::DB cla
 
 =head1 DESCRIPTION
 
-C<PAB::DB::Driver::Sqlite3> provides an interface to the sqlite3 library.
+C<PAB3::DB::Driver::Sqlite3> provides an interface to the sqlite3 library.
 
 How to get this module threadsafe?
 
@@ -241,7 +244,7 @@ If you plan using several connections in your scripts which may access to
 the same interpreter you should explicitly set $linkid in all expected
 functions.
 An alternative for this is the C<PAB3::DB> class. It takes care of it.
-See more at L<PAB3::DB>.
+See more at L<the PAB3::DB manpage|PAB3::DB>.
 
 =head2 Examples
 
@@ -321,7 +324,7 @@ Returns connection identifier ($linkid) on success or FALSE if an error occurs.
 
 =item db_connect ( %arg )
 
-Wrapper to open() used by L<PAB3::DB::connect()|PAB3::DB/item_connect>.
+Wrapper to open() used by L<PAB3::DB::connect()|PAB3::DB/connect>.
 
 Following arguments are supported:
 
@@ -342,8 +345,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -361,8 +364,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -381,8 +384,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -406,8 +409,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$query>
 
@@ -434,8 +437,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$query>
 
@@ -450,7 +453,8 @@ Returns a statement identifier ($stmtid) or FALSE if an error occured.
 
 B<See Also>
 
-L<execute>, L<bind_param>
+L<execute|PAB3::DB::Driver::Sqlite3/execute>,
+L<bind_param|PAB3::DB::Driver::Sqlite3/bind_param>
 
 
 =item bind_param ( $stmtid, $p_num )
@@ -465,7 +469,7 @@ B<Parameters>
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Sqlite3/prepare>.
 
 I<$p_num>
 
@@ -504,7 +508,8 @@ B<Parameters>
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare>.
 
 I<@bind_values>
 
@@ -534,20 +539,23 @@ TRUE on success or FALSE on error.
 =item affected_rows ( $stmtid )
 
 Gets the number of affected rows in a previous SQL operation
-After executing a statement with L<query()> or L<execute()>, returns the number
+After executing a statement with L<query()|PAB3::DB::Driver::Sqlite3/query> or
+L<execute()|PAB3::DB::Driver::Sqlite3/execute>, returns the number
 of rows changed (for UPDATE), deleted (for DELETE), or inserted (for INSERT).
-For SELECT statements, affected_rows() works like L<num_rows()>. 
+For SELECT statements, affected_rows() works like
+L<num_rows()|PAB3::DB::Driver::Sqlite3/num_rows>. 
 
 B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare>.
 
 B<Return Values>
 
@@ -569,12 +577,13 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare>.
 
 B<Return Values>
 
@@ -603,11 +612,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -625,11 +636,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -640,7 +653,7 @@ result set's columns or NULL if there are no more rows in resultset.
 If two or more columns of the result have the same field names, the last
 column will take precedence. To access the other column(s) of the same name,
 you either need to access the result with numeric indices by using
-L<fetch_row()> or add alias names.
+L<fetch_row()|PAB3::DB::Driver::Sqlite3/fetch_row> or add alias names.
 
 
 =item fetch_col ( $resid )
@@ -653,11 +666,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -675,11 +690,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -697,11 +714,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -718,11 +737,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -739,15 +760,18 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 I<$offset>
 
-Absolute row position. Valid between 0 and L<num_rows()> - 1.
+Absolute row position. Valid between 0 and
+L<num_rows()|PAB3::DB::Driver::Sqlite3/num_rows> - 1.
 
 B<Return Values>
 
@@ -770,11 +794,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -791,11 +817,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -816,11 +844,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 I<$offset>
 
@@ -842,11 +872,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -863,15 +895,18 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 I<$offset>
 
-Absolute field position. Valid between 0 and L<num_fields()> - 1.
+Absolute field position. Valid between 0 and
+L<num_fields()|PAB3::DB::Driver::Sqlite3/num_fields> - 1.
 
 B<Return Values>
 
@@ -894,11 +929,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Sqlite3/query>
+or L<execute()|PAB3::DB::Driver::Sqlite3/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by
+L<prepare()|PAB3::DB::Driver::Sqlite3/prepare> which has been executed.
 
 B<Return Values>
 
@@ -920,8 +957,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$mode>
 
@@ -943,8 +980,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -961,8 +998,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -979,8 +1016,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<open()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<open()|PAB3::DB::Driver::Sqlite3/open>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
